==> apache-iceberg-0.14.0.tar.gz: apache-iceberg-0.14.0/spark/v3.0/spark/src/test/java/org/apache/iceberg/spark/SparkCatalogTestBase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iceberg.spark;

import java.util.Map;
import org.junit.Rule;
import org.junit.rules.TemporaryFolder;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;

@RunWith(Parameterized.class)
public abstract class SparkCatalogTestBase extends SparkTestBaseWithCatalog {

  // these parameters are broken out to avoid changes that need to modify lots of test suites
  @Parameterized.Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}")
  public static Object[][] parameters() {
    return new Object[][] {{
                               SparkCatalogConfig.HIVE.catalogName(),
                               SparkCatalogConfig.HIVE.implementation(),
                               SparkCatalogConfig.HIVE.properties()
                           }, {
                               SparkCatalogConfig.HADOOP.catalogName(),
                               SparkCatalogConfig.HADOOP.implementation(),
                               SparkCatalogConfig.HADOOP.properties()
                           }, {
                               SparkCatalogConfig.SPARK.catalogName(),
                               SparkCatalogConfig.SPARK.implementation(),
                               SparkCatalogConfig.SPARK.properties()
                           }};
  }

  @Rule
  public TemporaryFolder temp = new TemporaryFolder();

  public SparkCatalogTestBase(SparkCatalogConfig config) {
    super(config);
  }

  public SparkCatalogTestBase(String catalogName, String implementation, Map<String, String> config) {
    super(catalogName, implementation, config);
  }
}

==> apache-iceberg-0.14.1.tar.gz: apache-iceberg-0.14.1/spark/v3.1/spark/src/test/java/org/apache/iceberg/spark/SparkCatalogTestBase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iceberg.spark;

import java.util.Map;
import org.junit.Rule;
import org.junit.rules.TemporaryFolder;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;

@RunWith(Parameterized.class)
public abstract class SparkCatalogTestBase extends SparkTestBaseWithCatalog {
  // these parameters are broken out to avoid changes that need to modify lots of test suites
  @Parameterized.Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}")
  public static Object[][] parameters() {
    return new Object[][] {
        {
          SparkCatalogConfig.HIVE.catalogName(),
          SparkCatalogConfig.HIVE.implementation(),
          SparkCatalogConfig.HIVE.properties()
        },
        {
          SparkCatalogConfig.HADOOP.catalogName(),
          SparkCatalogConfig.HADOOP.implementation(),
          SparkCatalogConfig.HADOOP.properties()
        },
        {
          SparkCatalogConfig.SPARK.catalogName(),
          SparkCatalogConfig.SPARK.implementation(),
          SparkCatalogConfig.SPARK.properties()
        }};
  }

  @Rule
  public TemporaryFolder temp = new TemporaryFolder();

  public SparkCatalogTestBase(SparkCatalogConfig config) {
    super(config);
  }

  public SparkCatalogTestBase(String catalogName, String implementation, Map<String, String> config) {
    super(catalogName, implementation, config);
  }
}
